@@ -1,4 +1,5 @@
 import re
+from urllib.error import HTTPError
 import warnings
 import pytz
 import pandas as pd
@@ -137,7 +138,7 @@ def MaterializationClient(
         What version of the api to use, 0: Legacy client (i.e www.dynamicannotationframework.com)
         2: new api version, (i.e. minniev1.microns-daf.com)
         'latest': default to the most recent (current 2)
-    cg_client: caveclient.chunkedgraph.ChunkeGraphClient
+    cg_client: caveclient.chunkedgraph.ChunkedGraphClient
         chunkedgraph client for live materializations
     synapse_table: str
         default synapse table for queries
@@ -222,7 +223,8 @@ class MaterializatonClientV2(ClientBase):
             version = self.most_recent_version()
         self._version = version
         if cg_client is None:
-            self.cg_client = self.fc.chunkedgraph
+            if self.fc is not None:
+                self.cg_client = self.fc.chunkedgraph
         else:
             self.cg_client = cg_client
         self.synapse_table = synapse_table
@@ -401,10 +403,11 @@ class MaterializatonClientV2(ClientBase):
 
     @cached(cache=TTLCache(maxsize=100, ttl=60 * 60 * 12))
     def get_table_metadata(
-        self, table_name: str, 
-        datastack_name=None, 
+        self,
+        table_name: str,
+        datastack_name=None,
         version: int = None,
-        log_warning: bool = True
+        log_warning: bool = True,
     ):
         """Get metadata about a table
 
@@ -414,10 +417,10 @@ class MaterializatonClientV2(ClientBase):
             datastack_name: str or None, optional,
                 Name of the datastack_name.
                 If None, uses the one specified in the client.
-            version (int, optional): 
+            version (int, optional):
                 version to get. If None, uses the one specified in the client.
-            log_warning (bool, optional): 
-                whether to print out warnings to the logger. 
+            log_warning (bool, optional):
+                whether to print out warnings to the logger.
                 Defaults to True.
 
         Returns:
@@ -504,7 +507,7 @@ class MaterializatonClientV2(ClientBase):
                 table_name=table,
                 datastack_name=datastack_name,
                 version=materialization_version,
-                log_warning=False
+                log_warning=False,
             )
             if md["reference_table"] is None:
                 target_table = None
@@ -541,6 +544,7 @@ class MaterializatonClientV2(ClientBase):
         metadata: bool = True,
         merge_reference: bool = True,
         desired_resolution: Iterable = None,
+        get_counts: bool = False,
     ):
         """generic query on materialization tables
 
@@ -633,6 +637,8 @@ class MaterializatonClientV2(ClientBase):
             offset,
             limit,
         )
+        if get_counts:
+            query_args["count"] = True
         response = self.session.post(
             url,
             data=json.dumps(data, cls=BaseEncoder),
@@ -655,7 +661,10 @@ class MaterializatonClientV2(ClientBase):
                             "desired resolution needs to be of length 3, for xyz"
                         )
                     vox_res = self.get_table_metadata(
-                        table, datastack_name, materialization_version, log_warning=False
+                        table,
+                        datastack_name,
+                        materialization_version,
+                        log_warning=False,
                     )["voxel_resolution"]
                     df = convert_position_columns(df, vox_res, desired_resolution)
             if metadata:
@@ -950,6 +959,246 @@ class MaterializatonClientV2(ClientBase):
 
         return df
 
+    def ingest_annotation_table(
+        self,
+        table_name: str,
+        datastack_name: str = None,
+    ):
+        """Trigger supervoxel lookup and rootID looksup of new annotations in a table.
+
+
+        Args:
+            table_name (str): table to drigger
+            datastack_name (str, optional): datastack to trigger it. Defaults to what is set in client.
+
+        Returns:
+            response: status code of response from server
+        """
+        if datastack_name is None:
+            datastack_name = self.datastack_name
+
+        endpoint_mapping = self.default_url_mapping
+        endpoint_mapping["datastack_name"] = datastack_name
+        endpoint_mapping["table_name"] = table_name
+        url = self._endpoints["ingest_annotation_table"].format_map(endpoint_mapping)
+        response = self.session.post(url)
+        return handle_response(response)
+
+    def lookup_supervoxel_ids(
+        self,
+        table_name: str,
+        annotation_ids: list = None,
+        datastack_name: str = None,
+    ):
+        """Trigger supervoxel lookups of new annotations in a table.
+
+
+        Args:
+            table_name (str): table to drigger
+            annotation_ids: (list, optional): list of annotation ids to lookup. Default is None,
+                                              which will trigger lookup of entire table.
+            datastack_name (str, optional): datastack to trigger it. Defaults to what is set in client.
+
+        Returns:
+            response: status code of response from server
+        """
+        if datastack_name is None:
+            datastack_name = self.datastack_name
+
+        if annotation_ids is not None:
+            data = {"annotation_ids": annotation_ids}
+        else:
+            data = {}
+        endpoint_mapping = self.default_url_mapping
+        endpoint_mapping["datastack_name"] = datastack_name
+        endpoint_mapping["table_name"] = table_name
+        url = self._endpoints["lookup_supervoxel_ids"].format_map(endpoint_mapping)
+        response = self.session.post(url, 
+                data=json.dumps(data, cls=BaseEncoder),
+                headers={
+                    "Content-Type": "application/json",
+                    "Accept-Encoding": "",
+                },)
+        return handle_response(response)
+
+    def live_live_query(
+        self,
+        table: str,
+        timestamp: datetime,
+        joins=None,
+        filter_in_dict=None,
+        filter_out_dict=None,
+        filter_equal_dict=None,
+        filter_spatial_dict=None,
+        select_columns=None,
+        offset: int = None,
+        limit: int = None,
+        datastack_name: str = None,
+        split_positions: bool = False,
+        metadata: bool = True,
+        suffixes: dict = None,
+        desired_resolution: Iterable = None,
+        allow_missing_lookups: bool = False,
+    ):
+        """Beta method for querying cave annotation tables with rootIDs and annotations at a particular
+        timestamp.  Note: this method requires more explicit mapping of filters and selection to table
+        as its designed to test a more general endpoint that should eventually support complex joins.
+
+        Args:
+            table (str): principle table to query
+            timestamp (datetime): timestamp to use for querying
+            joins (list): a list of joins, where each join is a list of [table1,column1, table2, column2]
+            filter_in_dict (dict, optional): a dictionary with tables as keys, values are dicts with column keys and list values to accept . Defaults to None.
+            filter_out_dict (dict, optional): a dictionary with tables as keys, values are dicts with column keys and list values to reject. Defaults to None.
+            filter_equal_dict (dict, optional):  a dictionary with tables as keys, values are dicts with column keys and values to equate. Defaults to None.
+            filter_spatial_dict (dict, optional): a dictionary with tables as keys, values are dicts with column keys and values of 2x3 list of bounds. Defaults to None.
+            select_columns (_type_, optional): a dictionary with tables as keys, values are list of columns. Defaults to None.
+            offset (int, optional): value to offset query by. Defaults to None.
+            limit (int, optional): limit of query. Defaults to None.
+            datastack_name (str, optional): datastack to query. Defaults to set by client.
+            split_positions (bool, optional): whether to split positions into seperate columns, True is faster. Defaults to False.
+            metadata (bool, optional): whether to attach metadata to dataframe. Defaults to True.
+            suffixes (dict, optional): what suffixes to use on joins, keys are table_names, values are suffixes. Defaults to None.
+            desired_resolution (Iterable, optional): What resolution to convert position columns to. Defaults to None will use defaults.
+            allow_missing_lookups (bool, optional): If there are annotations without supervoxels and rootids yet, allow results. Defaults to False.
+        Example:
+         live_live_query("table_name",datetime.datetime.utcnow(),
+            joins=[[table_name, table_column, joined_table, joined_column],
+                     [joined_table, joincol2, third_table, joincol_third]]
+            suffixes={
+                "table_name":"suffix1",
+                "joined_table":"suffix2",
+                "third_table":"suffix3"
+            },
+            select_columns= {
+                "table_name":[ "column","names"],
+                "joined_table":["joined_colum"]
+            },
+            filter_in_dict= {
+                "table_name":{
+                    "column_name":[included,values]
+                }
+            },
+            filter_out_dict= {
+                "table_name":{
+                    "column_name":[excluded,values]
+                }
+            },
+            filter_equal_dict"={
+                "table_name":{
+                    "column_name":value
+                },
+            filter_spatial_dict"= {
+                "table_name": {
+                "column_name": [[min_x, min_y, min_z], [max_x, max_y, max_z]]
+            }
+        }
+        Returns:
+            pd.DataFrame: result of query
+        """
+        logging.warning(
+            "Deprecation: this method is to facilitate beta testing of this feature, \
+it will likely get removed in future versions. "
+        )
+        timestamp = convert_timestamp(timestamp)
+        return_df = True
+        if datastack_name is None:
+            datastack_name = self.datastack_name
+
+        endpoint_mapping = self.default_url_mapping
+        endpoint_mapping["datastack_name"] = datastack_name
+        data = {}
+        query_args = {}
+        query_args["return_pyarrow"] = True
+        query_args["merge_reference"] = False
+        query_args["allow_missing_lookups"] = allow_missing_lookups
+        data["table"] = table
+        data["timestamp"] = timestamp
+        url = self._endpoints["live_live_query"].format_map(endpoint_mapping)
+        if joins is not None:
+            data["join_tables"] = joins
+        if filter_in_dict is not None:
+            data["filter_in_dict"] = filter_in_dict
+        if filter_out_dict is not None:
+            data["filter_notin_dict"] = filter_out_dict
+        if filter_equal_dict is not None:
+            data["filter_equal_dict"] = filter_equal_dict
+        if filter_spatial_dict is not None:
+            data["filter_spatial_dict"] = filter_spatial_dict
+        if select_columns is not None:
+            data["select_columns"] = select_columns
+        if offset is not None:
+            data["offset"] = offset
+        if limit is not None:
+            assert limit > 0
+            data["limit"] = limit
+        if suffixes is not None:
+            data["suffixes"] = suffixes
+        encoding = ""
+
+        response = self.session.post(
+            url,
+            data=json.dumps(data, cls=BaseEncoder),
+            headers={
+                "Content-Type": "application/json",
+                "Accept-Encoding": encoding,
+            },
+            params=query_args,
+            stream=~return_df,
+            verify=self.verify,
+        )
+        self.raise_for_status(response)
+
+        if desired_resolution is None:
+            desired_resolution = self.desired_resolution
+
+        with TimeIt("deserialize"):
+            with warnings.catch_warnings():
+                warnings.simplefilter(action="ignore", category=FutureWarning)
+                warnings.simplefilter(action="ignore", category=DeprecationWarning)
+                df = pa.deserialize(response.content)
+                if desired_resolution is not None:
+                    df = df.copy()
+                    if len(desired_resolution) != 3:
+                        raise ValueError(
+                            "desired resolution needs to be of length 3, for xyz"
+                        )
+                    vox_res = self.get_table_metadata(
+                        table_name=table,
+                        datastack_name=datastack_name,
+                        log_warning=False,
+                    )["voxel_resolution"]
+                    df = convert_position_columns(df, vox_res, desired_resolution)
+            if not split_positions:
+                concatenate_position_columns(df, inplace=True)
+
+        if metadata:
+            try:
+                attrs = self._assemble_attributes(
+                    table,
+                    join_query=False,
+                    filters={
+                        "inclusive": filter_in_dict,
+                        "exclusive": filter_out_dict,
+                        "equal": filter_equal_dict,
+                        "spatial": filter_spatial_dict,
+                    },
+                    select_columns=select_columns,
+                    offset=offset,
+                    limit=limit,
+                    live_query=timestamp is not None,
+                    timestamp=string_format_timestamp(timestamp),
+                    materialization_version=None,
+                    desired_resolution=desired_resolution,
+                )
+                df.attrs.update(attrs)
+            except HTTPError as e:
+                raise Exception(
+                    e.message
+                    + " Metadata could not be loaded, try with metadata=False if not needed"
+                )
+        return df
+
     def live_query(
         self,
         table: str,
@@ -1148,7 +1397,7 @@ class MaterializatonClientV2(ClientBase):
                         table_name=table,
                         datastack_name=datastack_name,
                         version=materialization_version,
-                        log_warning=False
+                        log_warning=False,
                     )["voxel_resolution"]
                     df = convert_position_columns(df, vox_res, desired_resolution)
             if not split_positions:
@@ -1210,7 +1459,10 @@ class MaterializatonClientV2(ClientBase):
         datastack_name: str = None,
         metadata: bool = True,
     ):
-        """query synapses
+        """Convience method for quering synapses. Will use the synapse table specified in the info service by default.
+        It will also remove autapses by default. NOTE: This is not designed to allow querying of the entire synapse table.
+        A query with no filters will return only a limited number of rows (configured by the server) and will do so in a non-deterministic fashion.
+        Please contact your dataset administrator if you want access to the entire table.
 
         Args:
             pre_ids (Union[int, Iterable, optional): pre_synaptic cell(s) to query. Defaults to None.
